@@ -1,6 +1,6 @@
 import json
-from lib.AIO import Aio
-from python.ahIOT.lib.TermalSensor.Extract_raw import get_frame, iterate
+from ahIOT.lib.AIO import Aio
+from ahIOT.lib.ThermalSensor.Extract_raw import get_frame, iterate
 
 def post_frame(data):
   Aio.send_stream(data)
